pub trait Contains<T> {
// Required method
fn contains(&self, obj: &T) -> bool;
}Expand description
Return true if a type contains a given object, otherwise false.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<T: FromStr + PartialOrd + Eq + Hash> Contains<T> for RangeOrSet<T>
impl<T: PartialOrd + Eq> Contains<T> for Range<T>
Return true if a type contains a given object, otherwise false.