Module utils

Module utils 

Macros

is_terminal
Return true if a given file descriptor is a terminal/tty, otherwise false.

Functions

config_dir
Get the user config directory for bugbite.
current_dir
Get the current working directory as an absolute Utf8PathBuf.